@@ -1,5 +1,5 @@
 makeShortcut <- function(dbfile="",wang2desktop=FALSE){
-#  if(grepl("win",tolower(.Platform$OS.type))){ ## Windows
+  if(grepl("win",tolower(.Platform$OS.type))){ ## Windows
     mixsepdir <- .find.package("mixsep")
     ## Create runmixsep.R script
     if(dbfile!=""){ ## If a file of DB connector information is given:
@@ -17,32 +17,21 @@ makeShortcut <- function(dbfile="",wang2desktop=FALSE){
         cat(" library(mixsep)\n mixsep()",file=paste(mixsepdir,"R","runmixsep.R",sep=.Platform$file.sep))
       }
       else{
-        ## Locates the line with 'db'-connection information
-        dbconnect <- rep(0,4)
-        for(line in c("dbtab","dbcase","dbcols")) dbconnect <- dbconnect + grepl(line,dblines)
-        dbconnect <- dblines[!dbconnect]
-        browser()
-#        dbAttempt <- try(odbcDriverConnect(dbconnect),silent=TRUE)
-#        if(class(dbAttempt)=="RODBC"){
-#          tkmessageBox(title="Database connection successful",message="Database connection successfully established",icon="info")
-          ## Writes information to runmixsep.R
-          dbcols <- grepl("dbcols",dblines)
-          dbcol <- unlist(lapply(strsplit(dblines[dbcols],"="),function(x) x[2]))
-          dbcol <- gsub("^\\s+|\\s+$","",unlist(strsplit(gsub("\"", "", dbcol),";")))
-          dblines[dbcols] <- paste("dbcols = c(\"",paste(gsub("^\\s+|\\s+$","",unlist(strsplit(gsub("\"", "", dbcol),";"))),collapse="\",\"",sep=""),"\")",sep="",collapse="")
-          cat(" library(mixsep)\n options(mixsep=list(",paste(dblines,collapse=","),"))\n mixsep()",file=paste(mixsepdir,"R","runmixsep.R",sep=.Platform$file.sep))
-#        }
-#        else{
-#          ## DB connection failed - This disables [DB] in GUI
-#          tkmessageBox(title="Database connection refused",message="Connection to the database refused",icon="error")
-#          cat(" library(mixsep)\n mixsep()",file=paste(mixsepdir,"R","runmixsep.R",sep=.Platform$file.sep))
-#        }
- #       odbcClose(dbAttempt)
+        ## Writes information to runmixsep.R
+        dbcols <- grepl("dbcols",dblines)
+        dbcol <- unlist(lapply(strsplit(dblines[dbcols],"="),function(x) x[2]))
+        dbcol <- gsub("^\\s+|\\s+$","",unlist(strsplit(gsub("\"", "", dbcol),";")))
+        dblines[dbcols] <- paste("dbcols = c(\"",paste(gsub("^\\s+|\\s+$","",unlist(strsplit(gsub("\"", "", dbcol),";"))),collapse="\",\"",sep=""),"\")",sep="",collapse="")
+        cat(" library(mixsep)\n options(mixsep=list(",paste(dblines,collapse=","),"))\n mixsep()",file=paste(mixsepdir,"R","runmixsep.R",sep=.Platform$file.sep))
       }
-    } ## If no DB connector is supplied - This disables [DB] in GUI
+    }
+    ## If no DB connector is supplied - This disables [DB] in GUI
     else cat(" library(mixsep)\n mixsep()",file=paste(mixsepdir,"R","runmixsep.R",sep=.Platform$file.sep))
-    ## Create .bat-file:
-    cat(paste(' @echo off \n start /MIN ', paste(R.home(),"bin","Rterm.exe",sep=.Platform$file.sep), ' -q -f ',
+    ## Change from 0.1-1 to 0.1-2
+    ## Changes due to difference between R2.11 and R2.12 where Rterm is moved to i386/ or x64/ (architechture dependent).
+    ## Hence, rather than using "Rterm.exe -q -f ../runmixsep.R" the call is now "Rscript.exe ../runmixsep.R"
+    ## Create .bat-file: 
+    cat(paste(' @echo off \n start /MIN ', paste(R.home(),"bin","Rscript.exe",sep=.Platform$file.sep), ' ',
                paste(mixsepdir,"R","runmixsep.R",sep=.Platform$file.sep), '\n'),
         file=paste(mixsepdir, "R", "mixsep.bat",sep=.Platform$file.sep))
     ## Create Visual Basic Script for shortcut creation:
@@ -62,10 +51,10 @@ makeShortcut <- function(dbfile="",wang2desktop=FALSE){
       filesys.CopyFile \"',wangfile,'\", strDesktopFld + "',.Platform$file.sep,'", true \n
       End If',sep=""), file=paste(mixsepdir,"R","shortcut.vbs",sep=.Platform$file.sep), append=TRUE)
     }
-    ## Create shortcut by calling VB script:
+    ## Create shortcut and/or copy wang.csv to desktop by calling VB script:
     shell(paste("CSCRIPT",paste(mixsepdir,"R","shortcut.vbs",sep=.Platform$file.sep)))
     ## Remove VB script:
     file.remove(paste(mixsepdir,"R","shortcut.vbs",sep=.Platform$file.sep))
-#  }
-#  else stop("Creation of shortcut is only possible for Windows operating systems")
+  }
+  else stop("Creation of shortcut is only possible for Windows operating systems")
 }
